@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-# $Id: runtests.pl,v 1.58 2002/04/09 14:28:16 bagder Exp $
+# $Id: runtests.pl,v 1.78 2003/04/01 08:41:49 bagder Exp $
 #
 # Main curl test script, in perl to run on more platforms
 #
@@ -7,6 +7,7 @@
 # These should be the only variables that might be needed to get edited:
 
 use strict;
+#use warnings;
 
 @INC=(@INC, $ENV{'srcdir'}, ".");
 
@@ -20,8 +21,10 @@ my $HTTPSPORT=8433; # this is the HTTPS server port
 my $FTPPORT=8921;  # this is the FTP server port
 my $FTPSPORT=8821;  # this is the FTPS server port
 my $CURL="../src/curl"; # what curl executable to run on the tests
+my $DBGCURL=$CURL; #"../src/.libs/curl";  # alternative for debugging
 my $LOGDIR="log";
 my $TESTDIR="data";
+my $LIBDIR="./libtest";
 my $SERVERIN="$LOGDIR/server.input"; # what curl sent the server
 my $CURLLOG="$LOGDIR/curl.log"; # all command lines run
 my $FTPDCMD="$LOGDIR/ftpserver.cmd"; # copy ftp server instructions here
@@ -48,6 +51,11 @@ my $perl="perl -I$srcdir";
 # this gets set if curl is compiled with memory debugging:
 my $memory_debug=0;
 
+# this gets set if curl is compiled with netrc debugging:
+# It has to be in the global symbol table because of the way 'requires' works
+$main::netrc_debug=0;
+my $netrc_debug = \$main::netrc_debug;
+
 # name of the file that the memory debugging creates:
 my $memdump="memdump";
 
@@ -58,6 +66,9 @@ my $checkstunnel = &checkstunnel;
 
 my $ssl_version; # set if libcurl is built with SSL support
 
+my $skipped=0;  # number of tests skipped; reported in main loop
+my $problems=0; # number of tests that didn't run due to run-time problems
+
 #######################################################################
 # variables the command line options may set
 #
@@ -72,6 +83,8 @@ my $listonly;     # only list the tests
 
 my $pwd;          # current working directory
 
+my %run;	  # running server
+
 chomp($pwd = `pwd`);
 
 # enable memory debugging if curl is compiled with it
@@ -84,7 +97,7 @@ $ENV{'HOME'}=$pwd;
 sub serverpid {
     my $PIDFILE = $_[0];
     open(PFILE, "<$PIDFILE");
-    my $PID=<PFILE>;
+    my $PID=0+<PFILE>;
     close(PFILE);
     return $PID;
 }
@@ -102,10 +115,10 @@ sub stopserver {
         unlink $PIDFILE; # server is killed
 
         if($res && $verbose) {
-            print "Test server pid $PID signalled to die\n";
+            print "RUN: Test server pid $PID signalled to die\n";
         }
         elsif($verbose) {
-            print "Test server pid $PID didn't exist\n";
+            print "RUN: Test server pid $PID didn't exist\n";
         }
     }
 }
@@ -147,42 +160,36 @@ sub runhttpserver {
     $pid = checkserver ($HTTPPIDFILE);
 
     # verify if our/any server is running on this port
-    my $data=`$CURL --silent -i $HOSTIP:$HOSTPORT/verifiedserver`;
+    my $cmd = "$CURL -o log/verifiedserver --silent -i $HOSTIP:$HOSTPORT/verifiedserver 2>/dev/null";
+    print "CMD; $cmd\n" if ($verbose);
+    my $res = system($cmd);
 
-    if ( $data =~ /WE ROOLZ(: |)(\d*)/ ) {
-        if($2) {
-            $pid = 0+$2;
-        }
+    $res >>= 8; # rotate the result
+    my $data;
 
-        if(!$pid) {
-            print "Test server already running with unknown pid! Use it...\n";
-            return;
-        }
+    print "RUN: curl command returned $res\n" if ($verbose);
 
-        if($verbose) {
-            print "Test server already running with pid $pid, killing it...\n";
-        }
+    open(FILE, "<log/verifiedserver");
+    my @file=<FILE>;
+    close(FILE);
+    $data=$file[0]; # first line
+
+    if ( $data =~ /WE ROOLZ: (\d+)/ ) {
+        $pid = 0+$1;
     }
-    elsif($data ne "") {
-        print "GOT: $data\n";
-        print "An alien HTTP server is running on port $HOSTPORT\n",
-        "Edit runtests.pl to use another port and rerun the test script\n";
-        exit;
-    }
-    else {
-        if($verbose) {
-            print "No server running, start it\n";
-        }
+    elsif($data) {
+        print "RUN: Unknown HTTP server is running on port $HOSTPORT\n";
+        return 2;
     }
 
     if($pid > 0) {
         my $res = kill (9, $pid); # die!
         if(!$res) {
-            print "Failed to kill our HTTP test server, do it manually and",
+            print "RUN: Failed to kill test HTTP server, do it manually and",
             " restart the tests.\n";
             exit;
         }
-        sleep(2);
+        sleep(1);
     }
 
     my $flag=$debugprotocol?"-v ":"";
@@ -192,6 +199,30 @@ sub runhttpserver {
         print "CMD: $cmd\n";
     }
 
+    my $verified;
+    for(1 .. 5) {
+        # verify that our server is up and running:
+        my $data=`$CURL --silent -i $HOSTIP:$HOSTPORT/verifiedserver 2>/dev/null`;
+
+        if ( $data !~ /WE ROOLZ: (\d+)/ ) {
+            sleep(1);
+            next;
+        }
+        else {
+            $verified = 1;
+            last;
+        }
+    }
+    if(!$verified) {
+        print STDERR "RUN: failed to start our HTTP server\n";
+        return 1;
+    }
+
+    if($verbose) {
+        print "RUN: HTTP server is now verified to be our server\n";
+    }
+
+    return 0;
 }
 
 #######################################################################
@@ -206,17 +237,18 @@ sub runhttpsserver {
     if($PID > 0) {
         # kill previous stunnel!
         if($verbose) {
-            print "kills off running stunnel at $PID\n";
+            print "RUN: kills off running stunnel at $PID\n";
         }
         stopserver($HTTPSPIDFILE);
     }
 
     my $flag=$debugprotocol?"-v ":"";
-    my $cmd="$perl $srcdir/httpsserver.pl $flag -r $HOSTPORT $HTTPSPORT &";
+    my $cmd="$perl $srcdir/httpsserver.pl $flag -d $srcdir -r $HOSTPORT $HTTPSPORT &";
     system($cmd);
     if($verbose) {
         print "CMD: $cmd\n";
     }
+    sleep(1);
 }
 
 #######################################################################
@@ -230,42 +262,75 @@ sub runftpserver {
     my $pid = checkserver ($FTPPIDFILE );
 
     if ($pid <= 0) {
-        my $flag=$debugprotocol?"-v ":"";
+        print "RUN: Check port $FTPPORT for our own FTP server\n"
+            if ($verbose);
 
-        # verify that our server is NOT running on this port:
-        my $data=`$CURL --silent -i ftp://$HOSTIP:$FTPPORT/verifiedserver`;
 
-        if ( $data =~ /WE ROOLZ/ ) {
-            print "A previous FTP server session is already running and we ",
-            "can't kill it!\n";
-            exit;
+        my $time=time();
+        # check if this is our server running on this port:
+        my $data=`$CURL -m4 --silent -i ftp://$HOSTIP:$FTPPORT/verifiedserver 2>/dev/null`;
+
+        # if this took more than 2 secs, we assume it "hung" on a weird server
+        my $took = time()-$time;
+        
+        if ( $data =~ /WE ROOLZ: (\d+)/ ) {
+            # this is our test server with a known pid!
+            $pid = $1;
         }
-
-        my $cmd="$perl $srcdir/ftpserver.pl $flag $FTPPORT &";
-        if($verbose) {
-            print "CMD: $cmd\n";
-        }
-        system($cmd);
-    }
-    else {
-        if($verbose) {
-            print "ftpd ($pid) is already running\n";
-        }
-
-        # verify that our server is one one running on this port:
-        my $data=`$CURL --silent -i ftp://$HOSTIP:$FTPPORT/verifiedserver`;
-
-        if ( $data !~ /WE ROOLZ/ ) {
-            print "Another FTP server is running on port $FTPPORT\n",
-            "Edit runtests.pl to use another FTP port and rerun the ",
-            "test script\n";
-            exit;
-        }
-
-        if($verbose) {
-            print "The running FTP server has been verified to be our server\n";
+        else {
+            if($data || ($took > 2)) {
+                # this is not a known server
+                print "RUN: Unknown server on our favourite port: $FTPPORT\n";
+                return 1;
+            }
         }
     }
+
+    if($pid > 0) {
+        print "RUN: Killing a previous server using pid $pid\n" if($verbose);
+        my $res = kill (9, $pid); # die!
+        if(!$res) {
+            print "RUN: Failed to kill our FTP test server, do it manually and",
+            " restart the tests.\n";
+            exit;
+        }
+        sleep(1);
+    }
+    
+    # now (re-)start our server:
+    my $flag=$debugprotocol?"-v ":"";
+    my $cmd="$perl $srcdir/ftpserver.pl $flag $FTPPORT &";
+    if($verbose) {
+        print "CMD: $cmd\n";
+    }
+    system($cmd);
+
+    my $verified;
+    for(1 .. 5) {
+        # verify that our server is up and running:
+        my $data=`$CURL --silent -i ftp://$HOSTIP:$FTPPORT/verifiedserver 2>/dev/null`;
+
+        if ( $data !~ /WE ROOLZ: (\d+)/ ) {
+            if($verbose) {
+                print STDERR "RUN: Retrying FTP server existance in 1 sec\n";
+            }
+            sleep(1);
+            next;
+        }
+        else {
+            $verified = 1;
+            last;
+        }
+    }
+    if(!$verified) {
+        die "RUN: failed to start our FTP server\n";
+    }
+
+    if($verbose) {
+        print "RUN: FTP server is now verified to be our server\n";
+    }
+
+    return 0;
 }
 
 #######################################################################
@@ -286,11 +351,12 @@ sub runftpsserver {
     }
 
     my $flag=$debugprotocol?"-v ":"";
-    my $cmd="$perl $srcdir/ftpsserver.pl $flag -r $FTPPORT $FTPSPORT &";
+    my $cmd="$perl $srcdir/ftpsserver.pl $flag -d $srcdir -r $FTPPORT $FTPSPORT &";
     system($cmd);
     if($verbose) {
         print "CMD: $cmd\n";
     }
+    sleep(1);
 }
 
 #######################################################################
@@ -390,14 +456,35 @@ sub displaydata {
         # enabled and we shall verify that no memory leaks exist
         # after each and every test!
         $memory_debug=1;
+
+        # there's only one debug control in the configure script
+        # so hope netrc debugging is enabled and set it up
+        $$netrc_debug = 1;
+        $ENV{'CURL_DEBUG_NETRC'} = 'log/netrc';
     }
     printf("* Memory debugging: %s\n", $memory_debug?"ON":"OFF");
+    printf("* Netrc debugging:  %s\n", $$netrc_debug?"ON":"OFF");
     printf("* HTTPS server:     %s\n", $checkstunnel?"ON":"OFF");
     printf("* FTPS server:      %s\n", $checkstunnel?"ON":"OFF");
     printf("* libcurl SSL:      %s\n", $ssl_version?"ON":"OFF");
     print "***************************************** \n";
 }
 
+#######################################################################
+# substitute the variable stuff into either a joined up file or 
+# a command, in either case passed by reference
+#
+sub subVariables {
+  my ($thing) = @_;
+  $$thing =~ s/%HOSTIP/$HOSTIP/g;
+  $$thing =~ s/%HOSTPORT/$HOSTPORT/g;
+  $$thing =~ s/%HTTPSPORT/$HTTPSPORT/g;
+  $$thing =~ s/%FTPPORT/$FTPPORT/g;
+  $$thing =~ s/%FTPSPORT/$FTPSPORT/g;
+  $$thing =~ s/%SRCDIR/$srcdir/g;
+  $$thing =~ s/%PWD/$pwd/g;
+}
+
 #######################################################################
 # Run a single specified test case
 #
@@ -409,17 +496,61 @@ sub singletest {
     if(loadtest("${TESTDIR}/test${testnum}")) {
         if($verbose) {
             # this is not a test
-            print "$testnum doesn't look like a test case!\n";
+            print "RUN: $testnum doesn't look like a test case!\n";
         }
         return -1;
     }
 
+    my $serverproblem = serverfortest($testnum);
+
+    if($serverproblem) {
+        # there's a problem with the server, don't run
+        # this particular server, but count it as "skipped"
+        if($serverproblem> 1) {
+            print "RUN: test case $testnum couldn't run!\n";
+            $problems++;
+        }
+        else {
+            $skipped++;
+        }
+        return -1;
+    }
+
+    {
+        my %hash = getpartattr("client");
+        my $requires = $hash{'requires'};
+
+        if (defined($requires)) {
+            no strict "refs";
+            my $value=${$requires};
+#            print "This test requires '$requires' with value '$value' \n";
+
+            if (${$requires}) {
+                # this test is OK
+                ;
+            }else {
+                print "$testnum requires $requires, which is not set; skipping\n";
+                $skipped++;
+                return -1;  # return test-not-run
+            }
+        }
+    }
+
+
     # extract the reply data
     my @reply = getpart("reply", "data");
     my @replycheck = getpart("reply", "datacheck");
 
     if (@replycheck) {
         # we use this file instead to check the final output against
+
+        my %hash = getpartattr("reply", "datacheck");
+        if($hash{'nonewline'}) {
+            # Yes, we must cut off the final newline from the final line
+            # of the datacheck
+            chomp($replycheck[$#replycheck]);
+        }
+    
         @reply=@replycheck;
     }
 
@@ -447,7 +578,7 @@ sub singletest {
     # name of the test
     my @testname= getpart("client", "name");
 
-    print "test $testnum...";
+    printf("test %03d...", $testnum);
     if(!$short) {
         my $name = $testname[0];
         $name =~ s/\n//g;
@@ -458,6 +589,14 @@ sub singletest {
         return 0; # look successful
     }
 
+    my @codepieces = getpart("client", "tool");
+
+    my $tool="";
+    if(@codepieces) {
+        $tool = $codepieces[0];
+        chomp $tool;
+    }
+
     # remove previous server output logfile
     unlink($SERVERIN);
 
@@ -471,13 +610,16 @@ sub singletest {
 
     # make some nice replace operations
     $cmd =~ s/\n//g; # no newlines please
-    $cmd =~ s/%HOSTIP/$HOSTIP/g;
-    $cmd =~ s/%HOSTPORT/$HOSTPORT/g;
-    $cmd =~ s/%HTTPSPORT/$HTTPSPORT/g;
-    $cmd =~ s/%FTPPORT/$FTPPORT/g;
-    $cmd =~ s/%FTPSPORT/$FTPSPORT/g;
-    $cmd =~ s/%SRCDIR/$srcdir/g;
-    $cmd =~ s/%PWD/$pwd/g;
+
+    subVariables \$cmd;
+
+#    $cmd =~ s/%HOSTIP/$HOSTIP/g;
+#    $cmd =~ s/%HOSTPORT/$HOSTPORT/g;
+#    $cmd =~ s/%HTTPSPORT/$HTTPSPORT/g;
+#    $cmd =~ s/%FTPPORT/$FTPPORT/g;
+#    $cmd =~ s/%FTPSPORT/$FTPSPORT/g;
+#    $cmd =~ s/%SRCDIR/$srcdir/g;
+#    $cmd =~ s/%PWD/$pwd/g;
 
     #$cmd =~ s/%HOSTNAME/$HOSTNAME/g;
 
@@ -491,11 +633,18 @@ sub singletest {
         my %hash = getpartattr("client", "file");
 
         my $filename=$hash{'name'};
+
         if(!$filename) {
             print "ERROR: section client=>file has no name attribute!\n";
             exit;
         }
-        writearray($filename, \@inputfile);
+        my $fileContent = join('', @inputfile);
+        subVariables \$fileContent;
+#        print "DEBUG: writing file " . $filename . "\n";
+        open OUTFILE, ">$filename";
+        binmode OUTFILE; # for crapage systems, use binary       
+        print OUTFILE $fileContent;
+        close OUTFILE;
     }
 
     my %cmdhash = getpartattr("client", "command");
@@ -507,12 +656,19 @@ sub singletest {
     }
     else {
         if (!@validstdout) {
-            $out="--output $CURLOUT ";
+            $out=" --output $CURLOUT ";
         }
     }
 
-    # run curl, add -v for debug information output
-    my $cmdargs="$out--include -v $cmd";
+    my $cmdargs;
+    if(!$tool) {
+        # run curl, add -v for debug information output
+        $cmdargs ="$out --include -v $cmd";
+    }
+    else {
+        $cmdargs = " $cmd"; # $cmd is the command line for the test file
+        $CURLOUT = $STDOUT; # sends received data to stdout
+    }
 
     my @stdintest = getpart("client", "stdin");
 
@@ -522,11 +678,21 @@ sub singletest {
 
         $cmdargs .= " <$stdinfile";
     }
-    my $CMDLINE="$CURL $cmdargs >$STDOUT 2>$STDERR";
+    my $CMDLINE;
+
+    if(!$tool) {
+        $CMDLINE="$CURL";
+    }
+    else {
+        $CMDLINE="$LIBDIR/$tool";
+        $DBGCURL=$CMDLINE;
+    }
+
+    $CMDLINE .= "$cmdargs >$STDOUT 2>$STDERR";
 
     if($verbose) {
-        print "$CMDLINE\n";
-    }
+        print "$CMDLINE\n"; 
+   }
 
     print CMDLOG "$CMDLINE\n";
 
@@ -537,7 +703,7 @@ sub singletest {
         print GDBCMD "set args $cmdargs\n";
         print GDBCMD "show args\n";
         close(GDBCMD);
-        system("gdb $CURL -x log/gdbcmd");
+        system("gdb $DBGCURL -x log/gdbcmd");
         $res =0; # makes it always continue after a debugged run
     }
     else {
@@ -553,7 +719,11 @@ sub singletest {
 
     if($errorcode || $res) {
         if($errorcode == $res) {
-            if(!$short) {
+            $errorcode =~ s/\n//;
+            if($verbose) {
+                print " received errorcode $errorcode OK";
+            }
+            elsif(!$short) {
                 print " error OK";
             }
         }
@@ -581,8 +751,7 @@ sub singletest {
     }
 
     my %replyattr = getpartattr("reply", "data");
-    if(!$replyattr{'nocheck'} &&
-       @reply) {
+    if(!$replyattr{'nocheck'} && @reply) {
         # verify the received data
         my @out = loadarray($CURLOUT);
         $res = compare(\@out, \@reply);
@@ -675,12 +844,25 @@ sub singletest {
 
     unlink($FTPDCMD); # remove the instructions for this test
 
+    my @what = getpart("client", "killserver");
+    for(@what) {
+        my $serv = $_;
+        chomp $serv;
+        if($run{$serv}) {
+            stopserver($run{$serv}); # the pid file is in the hash table
+            $run{$serv}=""; # clear it
+        }
+        else {
+            print STDERR "RUN: The $serv server is not running\n";
+        }
+    }
+
     if($memory_debug) {
         if(! -f $memdump) {
             print "\n** ALERT! memory debuggin without any output file?\n";
         }
         else {
-            my @memdata=`$memanalyze < $memdump`;
+            my @memdata=`$memanalyze $memdump`;
             my $leak=0;
             for(@memdata) {
                 if($_ ne "") {
@@ -709,8 +891,6 @@ sub singletest {
     return 0;
 }
 
-my %run;
-
 ##############################################################################
 # This function makes sure the right set of server is running for the
 # specified test case. This is a useful design when we run single tests as not
@@ -718,65 +898,107 @@ my %run;
 
 sub serverfortest {
     my ($testnum)=@_;
+    my @what;
 
     if($testnum< 100) {
         # 0 - 99 is for HTTP
-        if(!$run{'http'}) {
-            runhttpserver($verbose);
-            $run{'http'}=$HTTPPIDFILE;
-        }
+        push @what, "http";
     }
     elsif($testnum< 200) {
         # 100 - 199 is for FTP
-        if(!$run{'ftp'}) {
-            runftpserver($verbose);
-            $run{'ftp'}=$FTPPIDFILE;
-        }
+        push @what, "ftp";
     }
     elsif($testnum< 300) {
         # 200 - 299 is for FILE, no server!
-        $run{'file'}="moo";
+        push @what, "file";
     }
     elsif($testnum< 400) {
-        # 300 - 399 is for HTTPS, two servers!
-
-        if(!$checkstunnel || !$ssl_version) {
-            # we can't run https tests without stunnel
-            # or if libcurl is SSL-less
-            return 1;
-        }
-
-        if(!$run{'http'}) {
-            runhttpserver($verbose);
-            $run{'http'}=$HTTPPIDFILE;
-        }
-        if(!$run{'https'}) {
-            runhttpsserver($verbose);
-            $run{'https'}=$HTTPSPIDFILE;
-        }
+        # 300 - 399 is for HTTPS
+        push @what, "https";
     }
     elsif($testnum< 500) {
-        # 400 - 499 is for FTPS, also two servers
+        # 400 - 499 is for FTPS
+        push @what, "ftps";
+    }
 
-        if(!$checkstunnel || !$ssl_version) {
-            # we can't run https tests without stunnel
-            # or if libcurl is SSL-less
-            return 1;
+    if(!@what) {
+        # load the test case file definition
+        if(loadtest("${TESTDIR}/test${testnum}")) {
+            if($verbose) {
+                # this is not a test
+                print "$testnum doesn't look like a test case!\n";
+            }
+            return 100;
         }
-        if(!$run{'ftp'}) {
-            runftpserver($verbose);
-            $run{'ftp'}=$FTPPIDFILE;
-        }
-        if(!$run{'ftps'}) {
-            runftpsserver($verbose);
-            $run{'ftps'}=$FTPSPIDFILE;
+        @what = getpart("client", "server");
+
+        if(!$what[0]) {
+            warn "Test case $testnum has no server(s) specified!";
+            return 100;
         }
     }
-    else {
-        print "Bad test number, no server available\n";
-        return 100;
+    for(@what) {
+        my $what = lc($_);
+        $what =~ s/[^a-z]//g;
+        if($what eq "ftp") {
+            if(!$run{'ftp'}) {
+                if(runftpserver($verbose)) {
+                    return 2; # error starting it
+                }
+                $run{'ftp'}=$FTPPIDFILE;
+            }
+        }
+        elsif($what eq "http") {
+            if(!$run{'http'}) {
+                if(runhttpserver($verbose)) {
+                    return 2; # error starting
+                }
+                $run{'http'}=$HTTPPIDFILE;
+            }
+        }
+        elsif($what eq "ftps") {
+            if(!$checkstunnel || !$ssl_version) {
+                # we can't run https tests without stunnel
+                # or if libcurl is SSL-less
+                return 1;
+            }
+            if(!$run{'ftp'}) {
+                if(runftpserver($verbose)) {
+                    return 2; # error starting it
+                }
+                $run{'ftp'}=$FTPPIDFILE;
+            }
+            if(!$run{'ftps'}) {
+                runftpsserver($verbose);
+                $run{'ftps'}=$FTPSPIDFILE;
+            }
+        }
+        elsif($what eq "file") {
+            # we support it but have no server!
+        }
+        elsif($what eq "https") {
+            if(!$checkstunnel || !$ssl_version) {
+                # we can't run https tests without stunnel
+                # or if libcurl is SSL-less
+                return 1;
+            }
+            if(!$run{'http'}) {
+                if(runhttpserver($verbose)) {
+                    return 2; # problems starting server
+                }
+                $run{'http'}=$HTTPPIDFILE;
+            }
+            if(!$run{'https'}) {
+                runhttpsserver($verbose);
+                $run{'https'}=$HTTPSPIDFILE;
+            }
+        }
+        elsif($what eq "none") {
+        }
+        else {
+            warn "we don't support a server for $what";
+        }
     }
-    sleep 1; # give a second for the server(s) to startup
     return 0; # ok
 }
 
@@ -909,24 +1131,17 @@ my $failed;
 my $testnum;
 my $ok=0;
 my $total=0;
-my $skipped=0;
 
 foreach $testnum (split(" ", $TESTCASES)) {
 
-    my $serverproblem = serverfortest($testnum);
-
-    if($serverproblem) {
-        # there's a problem with the server, don't run
-        # this particular server, but count it as "skipped"
-        $skipped++;
+    my $error = singletest($testnum);
+    if(-1 == $error) {
+        # not a test we can run
         next;
     }
 
-    my $error = singletest($testnum);
-    if(-1 != $error) {
-        # valid test case number
-        $total++;
-    }
+    $total++; # number of tests we've run
+
     if($error>0) {
         $failed.= "$testnum ";
         if(!$anyway) {
@@ -936,7 +1151,7 @@ foreach $testnum (split(" ", $TESTCASES)) {
         }
     }
     elsif(!$error) {
-        $ok++;
+        $ok++; # successful test counter
     }
 
     # loop for next test
@@ -956,18 +1171,21 @@ for(keys %run) {
 }
 
 if($total) {
-    printf("$ok tests out of $total reported OK: %d%%\n",
+    printf("TESTDONE: $ok tests out of $total reported OK: %d%%\n",
            $ok/$total*100);
 
     if($ok != $total) {
-        print "These test cases failed: $failed\n";
+        print "TESTFAIL: These test cases failed: $failed\n";
     }
 }
 else {
-    print "No tests were performed!\n";
+    print "TESTFAIL: No tests were performed!\n";
 }
 if($skipped) {
-    print "$skipped tests were skipped due to restraints\n";
+    print "TESTINFO: $skipped tests were skipped due to restraints\n";
+}
+if($problems) {
+    print "TESTINFO: $problems tests didn't run due to run-time problems\n";
 }
 if($total && ($ok != $total)) {
     exit 1;
